@@ -5,9 +5,19 @@ from lib import desc_oper
 from lib import file_oper
 from lib import apps_oper
 from helpers import settings
+from pathlib import Path
+
 
 
 def main():
+    if settings.VERBOSE:
+        print(f'You are running this script from <{Path.cwd()}>')
+        print(f'Expecting charts structure like: {Path.joinpath(Path.cwd(),settings.TRAINS_PATH,"$TRAIN","$CHARTNAME")}')
+        print(f'Expecting dockerfile structure like: {Path.joinpath(Path.cwd(),settings.IMAGE_PATH,"$CHARTNAME","Dockerfile")}')
+        print(f'Port List Output set to: {Path.joinpath(Path.cwd(),settings.PORT_LIST_FILE)}')
+        print(f'Volume List Output set to: {Path.joinpath(Path.cwd(),settings.VOLUME_LIST_FILE)}')
+        print(f'Description List Output set to: {Path.joinpath(Path.cwd(),settings.DESCRIPTION_LIST_FILE)}')
+        
     if not settings.GENERATE_VOLUME_FILE and not settings.GENERATE_PORT_FILE and not settings.GENERATE_DESCRIPTION_FILE:
         print(Colors.RED + "No files to generate")
         exit(1)
@@ -30,6 +40,11 @@ def main():
         file_oper.delete_file(settings.DESCRIPTION_LIST_FILE)
 
     ordered_trains = apps_oper.get_ordered_trains(apps_oper.get_trains())
+
+    if ordered_trains is None:
+        print(Colors.RED + f'No trains found, does {settings.TRAINS_PATH} exists?')
+        exit(1)
+
     for train in ordered_trains:
         apps = apps_oper.get_apps(train)
         if settings.GENERATE_PORT_FILE:
